import csv
import numpy as np
import matplotlib
import matplotlib.pyplot as plt
import pandas as pd
import scipy.stats
import matplotlib.patches as mpatches
import seaborn as sns

########################################################################################################################

# Dataframe daily discharge for Helen Falls (HF) station
HF_df = pd.read_csv('DailyDischargeHelenFallsDate.csv')

HF_df['DOY'] = pd.DatetimeIndex(HF_df['Date']).dayofyear
HF_df['Year'] = pd.DatetimeIndex(HF_df['Date']).year
HF_df['Month'] = pd.DatetimeIndex(HF_df['Date']).month

HF_df = HF_df[HF_df['Year'] >= 1962]

HF_piv = pd.pivot_table(HF_df, index='DOY', columns='Year', values='Value')

HF_fig, HF_ax = plt.subplots(figsize=(10, 5))

HF_piv.plot(ax=HF_ax, xlabel=' ', ylabel='Discharge (m$^3$/s)', colormap='plasma')
plt.xticks(np.linspace(15,380,13)[:-1], ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'June', 'July', 'Aug', 'Sept', 'Oct', 'Nov', 'Dec'))
plt.xlim([1, 365])
#plt.yscale('log')
plt.grid(which='both')
plt.legend(loc='upper right', ncol=2)
plt.title('Yearly discharge at Helen Falls station from 1962 to 1979')
plt.savefig('Hydrograph_HF.png', dpi=200)

########################################################################################################################

# Dataframe daily discharge for Lac Hutte Sauvage (LHS) station
LHS_df = pd.read_csv('DailyDischargeLacHutteSauvageDate.csv')

LHS_df['DOY'] = pd.DatetimeIndex(LHS_df['Date']).dayofyear
LHS_df['Year'] = pd.DatetimeIndex(LHS_df['Date']).year
LHS_df['Month'] = pd.DatetimeIndex(LHS_df['Date']).month

LHS1_df = LHS_df[(LHS_df['Year'] >= 1975) & (LHS_df['Year'] <= 1999)]
LHS2_df = LHS_df[(LHS_df['Year'] >= 2008) & (LHS_df['Year'] <= 2019)]

LHS1_piv = pd.pivot_table(LHS1_df, index='DOY', columns='Year', values='Value')
LHS2_piv = pd.pivot_table(LHS2_df, index='DOY', columns='Year', values='Value')

LHS1_fig, LHS1_ax = plt.subplots(figsize=(10, 5))

LHS1_piv.plot(ax=LHS1_ax, xlabel=' ', ylabel='Discharge (m$^3$/s)', colormap='plasma')
plt.xticks(np.linspace(15,380,13)[:-1], ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'June', 'July', 'Aug', 'Sept', 'Oct', 'Nov', 'Dec'))
plt.xlim([1, 365])
#plt.yscale('log')
plt.grid(which='both')
plt.legend(loc='upper right', ncol=2)
plt.title('Yearly discharge at Lac de la Hutte Sauvage station from 1975 to 1999')
plt.savefig('Hydrograph_LHS_1975_1999.png', dpi=200)

LHS2_fig, LHS2_ax = plt.subplots(figsize=(10, 5))

LHS2_piv.plot(ax=LHS2_ax, xlabel=' ', ylabel='Discharge (m$^3$/s)', colormap='plasma')
plt.xticks(np.linspace(15,380,13)[:-1], ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'June', 'July', 'Aug', 'Sept', 'Oct', 'Nov', 'Dec'))
plt.xlim([1, 365])
#plt.yscale('log')
plt.grid(which='both')
plt.legend(loc='upper right', ncol=1)#, bbox_to_anchor=(1, 0.8))
plt.title('Yearly discharge at Lac de la Hutte Sauvage station from 2008 to 2019')
plt.savefig('Hydrograph_LHS_2008_2019.png', dpi=200)

########################################################################################################################